@@ -2,6 +2,7 @@ from .client import BotClient
 from .event import (
     GroupMessageEvent,
     PrivateMessageEvent,
+    MessageSentEvent,
     RequestEvent,
     NoticeEvent,
     MetaEvent,
@@ -34,6 +35,7 @@ __all__ = [
     "BotClient",
     "GroupMessageEvent",
     "PrivateMessageEvent",
+    "MessageSentEvent",
     "RequestEvent",
     "NoticeEvent",
     "MetaEvent",
