@@ -500,6 +500,17 @@ class GroupAPI(BaseAPI):
         result = await self.async_callback("/send_group_sign", {"group_id": group_id})
         APIReturnStatus.raise_if_failed(result)
 
+    async def get_group_album_list(self, group_id:Union[str, int]) -> list[dict]:
+        """获取群相册列表"""
+        result = await self.async_callback("/get_qun_album_list", {"group_id": group_id})
+        status = APIReturnStatus(result)
+        return status.data
+    
+    async def upload_image_to_group_album(self, group_id:Union[str, int], file:str, album_id:str="", album_name:str="") -> None:
+        """上传图片到群相册"""
+        result = await self.async_callback("/upload_image_to_qun_album", {"group_id": group_id, "album_name": album_name, "album_id": album_id, "file": file})
+        APIReturnStatus.raise_if_failed(result)
+
     # --------------
     # region 其它(管理员功能)
     # --------------
@@ -552,6 +563,13 @@ class GroupAPI(BaseAPI):
         )
         APIReturnStatus.raise_if_failed(result)
 
+    async def set_group_todo(self, group_id: Union[str, int], message_id: Union[str, int]) -> dict:
+        """设置群待办"""
+        result = await self.async_callback(
+            "/set_group_todo", {"group_id": group_id, "message_id": message_id}
+        )
+        APIReturnStatus.raise_if_failed(result)
+
     # ---------------------
     # region 同步版本接口
     # ---------------------
