@@ -26,6 +26,7 @@ from .event import (
     BaseEventData,
     PrivateMessageEvent,
     GroupMessageEvent,
+    MessageSentEvent,
     NoticeEvent,
     RequestEvent,
     MetaEvent,
@@ -36,6 +37,7 @@ from ..utils import NcatBotError, NcatBotConnectionError
 from ..utils import (
     OFFICIAL_PRIVATE_MESSAGE_EVENT,
     OFFICIAL_GROUP_MESSAGE_EVENT,
+    OFFICIAL_MESSAGE_SENT_EVENT,
     OFFICIAL_NOTICE_EVENT,
     OFFICIAL_REQUEST_EVENT,
     OFFICIAL_STARTUP_EVENT,
@@ -48,6 +50,7 @@ LOG = get_log("Client")
 EVENTS = (
     OFFICIAL_PRIVATE_MESSAGE_EVENT,
     OFFICIAL_GROUP_MESSAGE_EVENT,
+    OFFICIAL_MESSAGE_SENT_EVENT,
     OFFICIAL_NOTICE_EVENT,
     OFFICIAL_REQUEST_EVENT,
     OFFICIAL_STARTUP_EVENT,
@@ -112,6 +115,9 @@ class BotClient:
             self.add_group_message_handler(
                 make_async_handler(OFFICIAL_GROUP_MESSAGE_EVENT)
             )
+            self.add_message_sent_handler(
+                make_async_handler(OFFICIAL_MESSAGE_SENT_EVENT)
+            )
             self.add_notice_handler(make_async_handler(OFFICIAL_NOTICE_EVENT))
             self.add_request_handler(make_async_handler(OFFICIAL_REQUEST_EVENT))
             self.add_shutdown_handler(make_async_handler(OFFICIAL_SHUTDOWN_EVENT))
@@ -157,12 +163,25 @@ class BotClient:
                 handler(event)
 
         self.add_handler(OFFICIAL_PRIVATE_MESSAGE_EVENT, wrapper)
+    
+    def add_message_sent_handler(
+        self, handler: Callable[[MessageSentEvent], None], filter=None
+    ):
+        async def wrapper(event: MessageSentEvent):
+            new_messages = event.message.filter(filter)
+            if len(new_messages) == 0:
+                return
+            if inspect.iscoroutinefunction(handler):
+                await handler(event)
+            else:
+                handler(event)
+        self.add_handler(OFFICIAL_MESSAGE_SENT_EVENT, wrapper)
 
     def add_notice_handler(self, handler: Callable[[NoticeEvent], None], filter=None):
         self.add_handler(OFFICIAL_NOTICE_EVENT, handler)
 
     def add_request_handler(
-        self, handler: Callable[[RequestEvent], None], filter=Literal["group", "friend"]
+        self, handler: Callable[[RequestEvent], None], filter:Literal["group", "friend"] = "group"
     ):
         async def wrapper(event: RequestEvent):
             if filter != event.request_type:
@@ -211,6 +230,19 @@ class BotClient:
             return f  # 其实没有必要
 
         return decorator
+    
+    def on_message_sent(
+        self,
+        filter: Union[Type[MessageSegment], None] = None,
+    ):
+        """装饰器注册消息发送事件处理器"""
+        if filter is not None and not issubclass(filter, MessageSegment):
+            raise TypeError("filter 必须是 MessageSegment 的子类")
+
+        def decorator(f: Callable[[MessageSentEvent], None]):
+            self.add_message_sent_handler(f, filter)
+        
+        return decorator
 
     def on_notice(self, filter=None):
         """装饰器注册通知事件处理器"""
