@@ -20,6 +20,7 @@ from ncatbot.utils.assets import (
     REQUEST_SUCCESS,
     OFFICIAL_GROUP_MESSAGE_EVENT,
     OFFICIAL_PRIVATE_MESSAGE_EVENT,
+    OFFICIAL_MESSAGE_SENT_EVENT,
     OFFICIAL_REQUEST_EVENT,
     OFFICIAL_NOTICE_EVENT,
     OFFICIAL_STARTUP_EVENT,
@@ -74,6 +75,7 @@ __all__ = [
     "REQUEST_SUCCESS",
     "OFFICIAL_GROUP_MESSAGE_EVENT",
     "OFFICIAL_PRIVATE_MESSAGE_EVENT",
+    "OFFICIAL_MESSAGE_SENT_EVENT",
     "OFFICIAL_REQUEST_EVENT",
     "OFFICIAL_NOTICE_EVENT",
     "OFFICIAL_STARTUP_EVENT",
